@@ -1,7 +1,7 @@
 package PERLANCAR::Tree::Examples;
 
-our $DATE = '2016-04-03'; # DATE
-our $VERSION = '1.000.004'; # VERSION
+our $DATE = '2016-04-07'; # DATE
+our $VERSION = '1.0.5'; # VERSION
 
 use 5.010001;
 use strict;
@@ -92,9 +92,6 @@ sub gen_sample_data {
     );
 }
 
-# old name, for backward compatibility
-*gen_sample_tree = \&gen_sample_data;
-
 package # hide from PAUSE
     Tree::Example::HashNode;
 use parent qw(Tree::Object::Hash);
@@ -178,13 +175,13 @@ PERLANCAR::Tree::Examples - Generate sample tree object
 
 =head1 VERSION
 
-This document describes version 1.000.004 of PERLANCAR::Tree::Examples (from Perl distribution PERLANCAR-Tree-Examples), released on 2016-04-03.
+This document describes version 1.0.5 of PERLANCAR::Tree::Examples (from Perl distribution PERLANCAR-Tree-Examples), released on 2016-04-07.
 
 =head1 SYNOPSIS
 
- use PERLANCAR::Tree::Examples qw(gen_sample_tree);
+ use PERLANCAR::Tree::Examples qw(gen_sample_data);
 
- my $tree = gen_sample_tree(size => 'medium1');
+ my $tree = gen_sample_data(size => 'medium1');
 
 =head1 DESCRIPTION
 
@@ -321,8 +318,6 @@ C<Org::Document> tree generated when parsing my C<todo.org> document circa early
 
 Return value:  (obj)
 
-=for Pod::Coverage ^(gen_sample_tree)$
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-Tree-Examples>.
